#! /bin/bash
#
#---Ungrib GFS data for SFR ASMUA MHS onboard N18, N19, MetopA, MetopB
#   Usage: ./gfs_amsua_sfr.bash ${ff} ${yyyymmdd}
#                              ${ff}: GFS forecast Hour, ${yyyymmdd}: year month day.
#          e.g. gfs_atms_sfr.bash 06 20180625
#               Input: gfs.t06z.pgrb2.0p50.f000.20180225 
#               Output: gfs_comb06.bin,gfs_comb09.bin,gfs_comb12.bin,gfs_comb15.bin,gfs_comb18.bin
#
#   IMPORTANT: Make sure that the path set in the variable ${OutputBinDataDir} is
#   the same as the path set for variable ${nwpSfrGridPath} in the MiRS pcf file 
#   
#   Contact: Shu-Yan.Liu@noaa.gov
#   2018-07-09
#======================================================================================

. ../setup/gfs_amsua_sfr_pcf.bash

#---arguments
if [ $# -eq 2 ];  then
    ff=$1
    ymd=$2
else
    echo format: command ff yyyymmdd
    exit 1
fi

echo "The GFS data for Z$ff ${ymd} will be processed."

if [[ ${processMode} -eq 0 ]] ; then
   data_dir_output=${OutputBinDataDir}
   echo "orbital"
else
   data_dir_output=${OutputBinDataDir}/${ymd}
   echo "daily"
fi
if [ ! -d ${data_dir_output} ];  then
  mkdir -p ${data_dir_output}
fi

echo $data_dir_output


# prepare
yyyy=${ymd:0:4}
mm=${ymd:4:2}
dd=${ymd:6:2}

fhhs=(00 03 06 09 12)
if [ $ff -eq "00" ];  then 
    zhhs=(00 03 06 09 12)
elif [ $ff -eq "06" ];  then 
    zhhs=(06 09 12 15 18)
elif [ $ff -eq "12" ];  then
    zhhs=(12 15 18 21 24)
elif [ $ff -eq "18" ];  then
    zhhs=(18 21 24 27 30)
else
    echo Wrong forcast time
    exit 1
fi
nh=${#fhhs[@]}


# ungrib
##############################################
for ((ih=0; ih<${nh}; ih++)); do
  fhh=${fhhs[$ih]}
  zhh=${zhhs[$ih]}

  if [ $zhh -ge 24 ];  then
    rm -f $OutputBinDataDir/gfs_comb$zhh.bin
    if [[ ${processMode} -eq 0 ]] ; then
      zhh1=0$(($zhh - 24))
      echo $zhh1
      ln -s gfs_comb$zhh1.bin $OutputBinDataDir/gfs_comb$zhh.bin
    fi
  fi

  file1=${InputGribDataDir}/gfs.t${ff}z.pgrb2.0p50.f0${fhh}.${ymd}
  file_out=${data_dir_output}/gfs_comb${zhh}.bin

  if [ ! -f $file1 ]; then
    echo  "Following GFS File not found! " 
    echo  $file1
  fi

  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":10 mb:"   | ${WGRIB} \
      -i ${file1} -no_header -order we:ns         -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":20 mb:"   | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":30 mb:"   | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":50 mb:"   | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":70 mb:"   | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":100 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":150 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":200 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":250 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":300 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":350 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":400 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":450 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":500 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":550 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":600 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":650 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":700 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":750 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":800 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":850 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":900 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":925 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":950 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":975 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":HGT:"   | grep ":1000 mb:" | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}

  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":10 mb:"   | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":20 mb:"   | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":30 mb:"   | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":50 mb:"   | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":70 mb:"   | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":100 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":150 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":200 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":250 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":300 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":350 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":400 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":450 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":500 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":550 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":600 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":650 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":700 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":750 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":800 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":850 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":900 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":925 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":950 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":975 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"   | grep ":1000 mb:" | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}

  ${WGRIB} ${file1} | grep ":RH:"   | grep ":10 mb:"   | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":30 mb:"   | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":50 mb:"   | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":70 mb:"   | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":100 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":150 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":200 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":250 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":300 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":350 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":400 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":450 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":500 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":550 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":600 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":650 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":700 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":750 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":800 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":850 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":900 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":925 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":950 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":975 mb:"  | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":1000 mb:" | ${WGRIB} \
      -i ${file1} -no_header -order we:ns -append -bin ${file_out}

  ${WGRIB} ${file1} | grep ":PRES:" | grep ":surface:"          | ${WGRIB} \
      -i ${file1}  -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"  | grep ":surface:"          | ${WGRIB} \
      -i ${file1}  -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":TMP:"  | grep ":2 m above ground:" | ${WGRIB} \
      -i ${file1}  -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":RH:"   | grep ":2 m above ground:" | ${WGRIB} \
      -i ${file1}  -no_header -order we:ns -append -bin ${file_out}
  ${WGRIB} ${file1} | grep ":PWAT:" | grep ":entire atmosphere" | ${WGRIB} \
      -i ${file1}  -no_header -order we:ns -append -bin ${file_out}
done

exit 0

